@@ -7,9 +7,9 @@
 
 struct cfile {
   int fd;
-  FILE *fp;
+  void *fp;
   int comp;
-  unsigned int len;
+  size_t len;
   unsigned char buf[4096];
   int bufN;
   int eof;
@@ -17,7 +17,7 @@ struct cfile {
   void (*ctxup)(void *, unsigned char *, unsigned int);
   unsigned int crc;
   unsigned int crclen;
-  int bytes;
+  size_t bytes;
   int nunread;
   unsigned char *unreadbuf;
   union {
@@ -28,6 +28,7 @@ struct cfile {
   int (*write)(struct cfile *f, void *buf, int len);
   int (*close)(struct cfile *f);
   int (*unread)(struct cfile *f, void *buf, int len);
+  int (*oldread)(struct cfile *f, void *buf, int len);
 };
 
 typedef void (*cfile_ctxup)(void *, unsigned char *, unsigned int);
@@ -38,6 +39,9 @@ typedef void (*cfile_ctxup)(void *, unsigned char *, unsigned int);
 #define CFILE_IO_ALLOC  (-5)
 #define CFILE_IO_NULL   (-6)
 
+#define CFILE_IO_REOPEN     (-99)
+#define CFILE_IO_PUSHBACK   (-100)	/* internal */
+
 #define CFILE_COMP_XX (255)
 #define CFILE_COMP_UN (0)
 #define CFILE_COMP_GZ (1)
@@ -47,7 +51,7 @@ typedef void (*cfile_ctxup)(void *, unsigned char *, unsigned int);
 #define CFILE_OPEN_RD ('r')
 #define CFILE_OPEN_WR ('w')
 
-#define CFILE_LEN_UNLIMITED (-1)
+#define CFILE_LEN_UNLIMITED ((size_t)-1)
 
 #define CFILE_UNREAD_GET_LEN (-2)
 
@@ -57,6 +61,6 @@ typedef void (*cfile_ctxup)(void *, unsigned char *, unsigned int);
 
 #define CFILE_UNREAD_GETBYTES  (-2)
 
-struct cfile *cfile_open(int mode, int fd, void *fp, int comp, unsigned int len, void (*ctxup)(void *, unsigned char *, unsigned int), void *ctx);
+struct cfile *cfile_open(int mode, int fd, void *fp, int comp, size_t len, void (*ctxup)(void *, unsigned char *, unsigned int), void *ctx);
 int cfile_copy(struct cfile *in, struct cfile *out, int flags);
 int cfile_detect_rsync(struct cfile *f);
